summaryrefslogtreecommitdiffstats
path: root/ash/ash_switches.cc
diff options
context:
space:
mode:
Diffstat (limited to 'ash/ash_switches.cc')
-rw-r--r--ash/ash_switches.cc6
1 files changed, 5 insertions, 1 deletions
diff --git a/ash/ash_switches.cc b/ash/ash_switches.cc
index 1b9299e..150799a 100644
--- a/ash/ash_switches.cc
+++ b/ash/ash_switches.cc
@@ -76,7 +76,11 @@ const char kAshEnablePerAppLauncher[] = "ash-enable-per-app-launcher";
// Enables showing the tray bubble by dragging on the shelf.
const char kAshEnableTrayDragging[] = "ash-enable-tray-dragging";
-// Hides the small tab indicators at the top of the screen.
+// Enables immersive mode.
+const char kAshImmersiveMode[] = "ash-immersive-mode";
+
+// Enables immersive mode and hides the small tab indicators at the top of the
+// screen.
const char kAshImmersiveHideTabIndicators[] =
"ash-immersive-hide-tab-indicators";